@@ -1,6 +1,10 @@
 """Settings that need to be set in order to run the tests."""
+import logging
 import os
 
+
+logging.getLogger("factory").setLevel(logging.WARN)
+
 DEBUG = True
 
 SITE_ID = 1
@@ -19,8 +23,8 @@ DATABASES = {
 ROOT_URLCONF = 'social_media_links.tests.urls'
 
 STATIC_URL = '/static/'
-STATIC_ROOT = os.path.join(APP_ROOT, '../static')
-MEDIA_ROOT = os.path.join(APP_ROOT, '../media')
+STATIC_ROOT = os.path.join(APP_ROOT, '../app_static')
+MEDIA_ROOT = os.path.join(APP_ROOT, '../app_media')
 STATICFILES_DIRS = (
     os.path.join(APP_ROOT, 'static'),
 )
